pub struct CreatePoolInstructions {
pub instructions: Vec<Instruction>,
pub initialization_cost: u64,
pub pool_address: Pubkey,
pub additional_signers: Vec<Keypair>,
}Expand description
Represents the instructions and metadata for creating a pool.
Fields
instructions: Vec<Instruction>The list of instructions needed to create the pool.
initialization_cost: u64The estimated rent exemption cost for initializing the pool, in lamports.
pool_address: PubkeyThe address of the newly created pool.
additional_signers: Vec<Keypair>The list of signers for the instructions.